@@ -166,20 +166,22 @@ gdm_display_manage (GdmDisplay *d)
     if ( ! gdm_display_check_loop (d))
 	    return FALSE;
 
-    gdm_sigchld_block_push ();
+    if (d->slavepid != 0)
+	    gdm_debug ("gdm_display_manage: Old slave pid is %d", (int)d->slavepid);
 
     /* If we have an old slave process hanging around, kill it */
-    if (d->slavepid) {
-	    if (kill (d->slavepid, SIGINT) == 0)
-		    ve_waitpid_no_signal (d->slavepid, 0, 0);
-	    d->slavepid = 0;
-    }
+    gdm_sigchld_block_push ();
+    if (d->slavepid > 1 &&
+	kill (d->slavepid, SIGTERM) == 0)
+	    ve_waitpid_no_signal (d->slavepid, 0, 0);
+    d->slavepid = 0;
+    gdm_sigchld_block_pop ();
 
     /* Fork slave process */
+    gdm_sigchld_block_push ();
     gdm_sigterm_block_push ();
     pid = d->slavepid = fork ();
     gdm_sigterm_block_push ();
-
     gdm_sigchld_block_pop ();
 
     switch (pid) {
@@ -187,6 +189,13 @@ gdm_display_manage (GdmDisplay *d)
     case 0:
 	setpgid (0, 0);
 
+	/* Make the slave it's own leader.  This 1) makes killing -pid of
+	 * the daemon work more sanely because the daemon can whack the
+	 * slave much better itself */
+	setsid ();
+
+	d->slavepid = getpid ();
+
 	/* Close XDMCP fd in slave process */
 	if (GdmXdmcp)
 	    gdm_xdmcp_close ();
@@ -203,9 +212,9 @@ gdm_display_manage (GdmDisplay *d)
 
 	/* No error checking here - if it's messed the best response
          * is to ignore & try to continue */
-	open("/dev/null", O_RDONLY); /* open stdin - fd 0 */
-	open("/dev/null", O_RDWR); /* open stdout - fd 1 */
-	open("/dev/null", O_RDWR); /* open stderr - fd 2 */
+	gdm_open_dev_null (O_RDONLY); /* open stdin - fd 0 */
+	gdm_open_dev_null (O_RDWR); /* open stdout - fd 1 */
+	gdm_open_dev_null (O_RDWR); /* open stderr - fd 2 */
 
 	openlog ("gdm", LOG_PID, LOG_DAEMON);
 
@@ -237,6 +246,7 @@ gdm_display_manage (GdmDisplay *d)
 	break;
 
     case -1:
+	d->slavepid = 0;
 	gdm_error (_("gdm_display_manage: Failed forking gdm slave process for %s"), d->name);
 
 	return FALSE;
@@ -277,11 +287,12 @@ gdm_display_unmanage (GdmDisplay *d)
 	       d->name, (int)d->slavepid);
 
     /* Kill slave */
-    if (d->slavepid != 0) {
-	if (kill (d->slavepid, SIGTERM) == 0)
-		ve_waitpid_no_signal (d->slavepid, 0, 0);
-	d->slavepid = 0;
-    }
+    gdm_sigchld_block_push ();
+    if (d->slavepid > 1 &&
+	kill (d->slavepid, SIGTERM) == 0)
+	    ve_waitpid_no_signal (d->slavepid, 0, 0);
+    d->slavepid = 0;
+    gdm_sigchld_block_pop ();
     
     if (d->type == TYPE_LOCAL)
 	d->dispstat = DISPLAY_DEAD;
@@ -347,6 +358,11 @@ gdm_display_dispose (GdmDisplay *d)
     g_free (d->authfile_gdm);
     d->authfile_gdm = NULL;
 
+    if (d->xnest_temp_auth_file != NULL)
+	    unlink (d->xnest_temp_auth_file);
+    g_free (d->xnest_temp_auth_file);
+    d->xnest_temp_auth_file = NULL;
+
     if (d->auths) {
 	GSList *tmpauth = d->auths;
 
