@@ -230,7 +230,7 @@ gboolean
 gdm_xdmcp_init (void)
 {
     struct sockaddr_in serv_sa = {0};
-    gchar hostbuf[256];
+    gchar hostbuf[1024];
     struct utsname name;
 
     if ( ! GdmXdmcp)
@@ -239,7 +239,8 @@ gdm_xdmcp_init (void)
     globsessid = time (NULL);
     
     /* Fetch and store local hostname in XDMCP friendly format */
-    if (gethostname (hostbuf, 255) != 0) {
+    hostbuf[1023] = '\0';
+    if (gethostname (hostbuf, 1023) != 0) {
 	gdm_error (_("gdm_xdmcp_init: Could not get server hostname: %s!"), strerror (errno));
 	strcmp (hostbuf, "localhost.localdomain");
     }
@@ -286,6 +287,7 @@ gdm_xdmcp_run (void)
 	GIOChannel *xdmcpchan;
 
 	xdmcpchan = g_io_channel_unix_new (gdm_xdmcpfd);
+	g_io_channel_set_encoding (xdmcpchan, NULL, NULL);
 	g_io_channel_set_buffered (xdmcpchan, FALSE);
 
 	xdmcp_source = g_io_add_watch_full
@@ -1533,9 +1535,9 @@ gdm_xdmcp_display_alloc (struct in_addr *addr, const char *hostname, gint displa
 
     d->handled = TRUE;
 
-#ifdef __linux__
     d->vt = -1;
-#endif
+
+    d->x_servers_order = -1;
 
     d->logged_in = FALSE;
     d->login = NULL;
