@@ -1,6 +1,8 @@
 /* Glade helper routines
+ *
  * Author: George Lebl
  * (c) 2000 Eazel, Inc.
+ * (c) 2002 George Lebl
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -19,6 +21,10 @@
  */
 
 #include <config.h>
+
+/* For clist */
+#undef GTK_DISABLE_DEPRECATED
+
 #include <libgnome/libgnome.h>
 #include <libgnomeui/libgnomeui.h>
 #include <glade/glade.h>
@@ -30,17 +36,18 @@
 static void glade_helper_no_interface (const char *filename);
 static void glade_helper_bad_interface (const char *filename,
 					const char *widget,
-					GtkType type);
+					GType type);
 static void glade_helper_bad_columns (const char *filename,
 				      const char *widget,
-				      GtkType type,
+				      GType type,
 				      int columns);
 
 static GList *ve_glade_directories = NULL;
+static gboolean ve_search_gnome_dirs = TRUE;
 
 GladeXML *
 glade_helper_load (const char *file, const char *widget,
-		   GtkType expected_type,
+		   GType expected_type,
 		   gboolean dump_on_destroy)
 {
 	char *f;
@@ -53,7 +60,7 @@ glade_helper_load (const char *file, const char *widget,
 
 	if (f == NULL) {
 		glade_helper_no_interface (file);
-		gtk_exit (1);
+		exit (1);
 	}
 
 	/* FIXME: eek use of PACKAGE */
@@ -64,7 +71,7 @@ glade_helper_load (const char *file, const char *widget,
 	/* in case we can't load the interface, bail */
 	if (xml == NULL) {
 		glade_helper_no_interface (file);
-		gtk_exit (1);
+		exit (1);
 	}
 
 	w = glade_xml_get_widget (xml, widget);
@@ -75,7 +82,7 @@ glade_helper_load (const char *file, const char *widget,
 					      _("(memory buffer)"),
 					    widget,
 					    expected_type);
-		gtk_exit (1);
+		exit (1);
 	}
 
 	if (dump_on_destroy) {
@@ -90,7 +97,7 @@ glade_helper_load (const char *file, const char *widget,
 
 GtkWidget *
 glade_helper_load_widget (const char *file, const char *widget,
-			  GtkType expected_type)
+			  GType expected_type)
 {
 	GladeXML *xml;
 	GtkWidget *w;
@@ -107,7 +114,7 @@ glade_helper_load_widget (const char *file, const char *widget,
 					      _("(memory buffer"),
 					    widget,
 					    expected_type);
-		gtk_exit (1);
+		exit (1);
 	}
 
 	g_object_unref (G_OBJECT (xml));
@@ -116,7 +123,7 @@ glade_helper_load_widget (const char *file, const char *widget,
 }
 
 GtkWidget *
-glade_helper_get (GladeXML *xml, const char *widget, GtkType expected_type)
+glade_helper_get (GladeXML *xml, const char *widget, GType expected_type)
 {
 	GtkWidget *w;
 
@@ -129,7 +136,7 @@ glade_helper_get (GladeXML *xml, const char *widget, GtkType expected_type)
 					      _("(memory buffer"),
 					    widget,
 					    expected_type);
-		gtk_exit (1);
+		exit (1);
 	}
 
 	return w;
@@ -137,7 +144,7 @@ glade_helper_get (GladeXML *xml, const char *widget, GtkType expected_type)
 
 GtkWidget *
 glade_helper_get_clist (GladeXML *xml, const char *widget,
-			GtkType expected_type, int expected_columns)
+			GType expected_type, int expected_columns)
 {
 	GtkWidget *w;
 
@@ -150,7 +157,7 @@ glade_helper_get_clist (GladeXML *xml, const char *widget,
 					  widget,
 					  expected_type,
 					  expected_columns);
-		gtk_exit (1);
+		exit (1);
 	}
 
 	return w;
@@ -158,14 +165,14 @@ glade_helper_get_clist (GladeXML *xml, const char *widget,
 
 static void
 glade_helper_bad_interface (const char *filename, const char *widget,
-			    GtkType type)
+			    GType type)
 {
 	GtkWidget *dlg;
 	char *typestring;
 	const char *typename;
 
 	if (type != 0)
-		typename = gtk_type_name (type);
+		typename = g_type_name (type);
 	else
 		typename = NULL;
 
@@ -204,14 +211,14 @@ glade_helper_bad_interface (const char *filename, const char *widget,
 
 static void
 glade_helper_bad_columns (const char *filename, const char *widget,
-			  GtkType type, int columns)
+			  GType type, int columns)
 {
 	GtkWidget *dlg;
 	char *typestring;
 	const char *typename;
 
 	if (type != 0)
-		typename = gtk_type_name (type);
+		typename = g_type_name (type);
 	else
 		typename = NULL;
 
@@ -294,7 +301,10 @@ glade_helper_find_glade_file (const char *file)
 {
 	g_return_val_if_fail (file != NULL, NULL);
 
-	return ve_find_file (file, ve_glade_directories);
+	if (ve_search_gnome_dirs)
+		return ve_find_file (file, ve_glade_directories);
+	else
+		return ve_find_file_simple (file, ve_glade_directories);
 }
 
 /**
@@ -310,3 +320,20 @@ glade_helper_add_glade_directory (const char *directory)
 	ve_glade_directories = g_list_append (ve_glade_directories,
 					      g_strdup (directory));
 }
+
+/**
+ * glade_helper_seach_gnome_dirs:
+ * @search_gnome_dirs:  boolean
+ *
+ * Description:  Sets if the gnome directories are searched.  Useful if
+ * your program does not use gnome_program_ and you don't want glade_helper
+ * to invoke gnome_program initialization by mistake.  This is because
+ * it is possible for glade helper to try to use gnome_program_ routines
+ * by default.
+ **/
+void
+glade_helper_search_gnome_dirs (gboolean search_gnome_dirs)
+{
+	ve_search_gnome_dirs = search_gnome_dirs;
+}
+
