@@ -68,6 +68,44 @@ ve_first_word (const char *s)
 	return ret;
 }
 
+gboolean
+ve_first_word_executable (const char *s, gboolean only_existance)
+{
+	char *bin = ve_first_word (s);
+	if (bin == NULL)
+		return FALSE;
+	if (access (bin, only_existance ? F_OK : X_OK) == 0) {
+		g_free (bin);
+		return TRUE;
+	} else {
+		g_free (bin);
+		return FALSE;
+	}
+}
+
+char *
+ve_get_first_working_command (const char *list,
+			      gboolean only_existance)
+{
+	int i;
+	char **vector;
+	char *ret = NULL;
+
+	if (list == NULL)
+		return NULL;
+       
+	vector = g_strsplit (list, ";", -1);
+	for (i = 0; vector[i] != NULL; i++) {
+		if (ve_first_word_executable (vector[i],
+					      only_existance)) {
+			ret = g_strdup (vector[i]);
+			break;
+		}
+	}
+	g_strfreev (vector);
+	return ret;
+}
+
 char *
 ve_rest (const char *s)
 {
@@ -183,12 +221,9 @@ ve_is_string_in_list_case_no_locale (const GList *list, const char *string)
 }
 
 char *
-ve_find_file (const char *filename, const GList *directories)
+ve_find_file_simple (const char *filename, const GList *directories)
 {
-	char *s, *ss;
-	const char *path;
-	char **pathv;
-	int i;
+	char *s;
 	const GList *li;
 
 	if (filename == NULL)
@@ -208,6 +243,26 @@ ve_find_file (const char *filename, const GList *directories)
 		g_free (s);
 	}
 
+	return NULL;
+}
+
+char *
+ve_find_file (const char *filename, const GList *directories)
+{
+	char *s, *ss;
+	const char *path;
+	char **pathv;
+	int i;
+
+	s = ve_find_file_simple (filename, directories);
+	if (s != NULL)
+		return s;
+	/* if the filename was NULL or absolute
+	 * no further checks are made */
+	if (filename == NULL ||
+	    g_path_is_absolute (filename))
+		return NULL;
+
 	s = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
 				       filename, TRUE, NULL);
 	if (s != NULL)
@@ -312,3 +367,17 @@ ve_waitpid_no_signal (pid_t pid, int *status, int options)
 			return ret;
 	}
 }
+
+gboolean
+ve_locale_exists (const char *loc)
+{
+	gboolean ret;
+	char *old = g_strdup (setlocale (LC_ALL, NULL));
+	if (setlocale (LC_MESSAGES, loc) != NULL)
+		ret = TRUE;
+	else
+		ret = FALSE;
+	setlocale (LC_MESSAGES, old);
+	g_free (old);
+	return ret;
+}
